@@ -101,4 +101,43 @@ class SQLServer(AbcDatabase):
     def create_engine(self):
         params = urllib.parse.quote_plus(self.conn_string)
         create_engine_string = "mssql+pyodbc:///?odbc_connect=%s" % params
-        return create_engine(create_engine_string)
\ No newline at end of file
+        return create_engine(create_engine_string)
+
+    def pk_columns(self, table):
+        sql = f'''
+        SELECT COLUMN_NAME
+        FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
+        WHERE OBJECTPROPERTY(OBJECT_ID(CONSTRAINT_SCHEMA + '.' + QUOTENAME(CONSTRAINT_NAME)), 'IsPrimaryKey') = 1
+        AND TABLE_NAME = '{table}' AND TABLE_SCHEMA = 'dbo'
+        '''
+        list_columns = self.fetchCol(sql)
+        if len(list_columns) == 0:
+            return None
+        str_columns = ','.join(list_columns)
+        return str_columns
+
+    def cdc_statistics(self, table, dbname=None, schema='dbo'):
+        if dbname is None:
+            dbname = self.dbname
+        # Get PK Columns
+        sql = f'''
+        SELECT COLUMN_NAME
+        FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE
+        WHERE OBJECTPROPERTY(OBJECT_ID(CONSTRAINT_SCHEMA + '.' + QUOTENAME(CONSTRAINT_NAME)), 'IsPrimaryKey') = 1
+        AND TABLE_NAME = '{table}' AND TABLE_SCHEMA = 'dbo'
+        '''
+        pkcolumns_list = self.fetchCol(sql)
+        if len(pkcolumns_list) == 0:
+            raise f"Table has not PRIMARY KEY"
+        # Obtain All Changes
+        pkcolumns = ','.join(pkcolumns_list)
+        sql = f'''
+        SELECT 
+            SYS_CHANGE_OPERATION,
+            count(SYS_CHANGE_OPERATION) changes
+        FROM CHANGETABLE(CHANGES [{dbname}].[{schema}].[{table}],0) AS CT
+        GROUP BY SYS_CHANGE_OPERATION
+        '''
+
+        df = self.fetchAll(sql)
+        return df
